@@ -29,6 +29,8 @@ import pydoop.hadoop_utils as hu
 import pydoop.hdfs as hdfs
 
 
+GLOB_CHARS = frozenset('*,?[]{}')
+
 #--- FIXME: perhaps we need a more sophisticated tool for setting args ---
 GENERIC_ARGS = frozenset([
   "-conf", "-D", "-fs", "-jt", "-files", "-libjars", "-archives"
@@ -77,6 +79,23 @@ def _merge_csv_args(args):
 def _construct_property_args(prop_dict):
   return sum((['-D', '%s=%s' % p] for p in prop_dict.iteritems()), [])
 
+class RunCmdError(RuntimeError): # inherits from RuntimeError for backwards compatibility
+  """
+  This exception is raised by run_cmd and all functions that make use of it to
+  indicate that the call failed (returned non-zero).
+  """
+  def __init__(self, returncode, cmd, output=None):
+    RuntimeError.__init__(self, output)
+    self.returncode = returncode
+    self.cmd = cmd
+
+  def __str__(self):
+    m = RuntimeError.__str__(self)
+    if m:
+      return m # mimic old run_cmd behaviour
+    else:
+      return "Command '%s' returned non-zero exit status %d" % (self.cmd, self.returncode)
+
 
 def run_cmd(cmd, args=None, properties=None, hadoop_home=None,
             hadoop_conf_dir=None, logger=None):
@@ -84,7 +103,7 @@ def run_cmd(cmd, args=None, properties=None, hadoop_home=None,
   Run a Hadoop command.
 
   If the command succeeds, return its output; if it fails, raise a
-  ``RuntimeError`` with its error output as the message.
+  ``RunCmdError`` with its error output as the message.
 
   .. code-block:: python
 
@@ -98,7 +117,7 @@ def run_cmd(cmd, args=None, properties=None, hadoop_home=None,
     -report: Reports basic filesystem information and statistics.
     >>> try:
     ...     run_cmd('foo')
-    ... except RuntimeError as e:
+    ... except RunCmdError as e:
     ...     print e
     ...
     Exception in thread "main" java.lang.NoClassDefFoundError: foo
@@ -120,10 +139,11 @@ def run_cmd(cmd, args=None, properties=None, hadoop_home=None,
     gargs = _pop_generic_args(args)
     for seq in gargs, args:
       _args.extend(map(str, seq))
+  logger.info('args %s, cmd %s, properties %s', _args, cmd, properties)
   p = subprocess.Popen(_args, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
   output, error = p.communicate()
   if p.returncode:
-    raise RuntimeError(error)
+    raise RunCmdError(p.returncode, ' '.join(_args), error)
   return output
 
 
@@ -211,7 +231,7 @@ def run_jar(jar_name, more_args=None, properties=None, hadoop_conf_dir=None):
     >>> more_args = ['wordcount']
     >>> try:
     ...     run_jar(jar_name, more_args=more_args)
-    ... except RuntimeError as e:
+    ... except RunCmdError as e:
     ...     print e
     ...
     Usage: wordcount <in> <out>
@@ -247,6 +267,7 @@ def run_class(class_name, args=None, properties=None, classpath=None,
       classpath = [classpath]
     classpath_list = [cp.strip() for s in classpath for cp in s.split(":")]
     os.environ['HADOOP_CLASSPATH'] = ":".join(classpath_list)
+    logger.debug('HADOOP_CLASSPATH %s',  os.environ['HADOOP_CLASSPATH'] )
   res = run_cmd(class_name, args, properties, hadoop_conf_dir=hadoop_conf_dir,
                 logger=logger)
   if old_classpath is not None:
@@ -275,9 +296,10 @@ def run_pipes(executable, input_path, output_path, more_args=None,
   """
   if logger is None:
     logger = utils.NullLogger()
-  for n, p in ("executable", executable), ("input path", input_path):
-    if not hdfs.path.exists(p):
-      raise IOError("%s not found" % n)
+  if not hdfs.path.exists(executable):
+    raise IOError("executable %s not found" % executable)
+  if not hdfs.path.exists(input_path) and not(set(input_path) & GLOB_CHARS):
+    raise IOError("input path %s not found" % input_path)
   if properties is None:
     properties = {}
   properties.setdefault('hadoop.pipes.java.recordreader', 'true')
@@ -302,7 +324,8 @@ def run_pipes(executable, input_path, output_path, more_args=None,
     submitter = "it.crs4.pydoop.pipes.Submitter"
     pydoop_jar = pydoop.jar_path()
     args.extend(("-libjars", pydoop_jar))
-    return run_class(submitter, args, properties, classpath=pydoop_jar,
+    return run_class(submitter, args, properties, 
+    classpath=pydoop_jar,
                      logger=logger)
   else:
     return run_cmd("pipes", args, properties, hadoop_conf_dir=hadoop_conf_dir,
@@ -445,6 +468,7 @@ class PipesRunner(object):
     self.logger.info("collecting output%s" % (
       " to %s" % out_file if out_file else ''
       ))
+    self.logger.info("self.output %s", self.output)
     return collect_output(self.output, out_file)
 
   def __str__(self):
