@@ -39,4 +39,6 @@ def suite():
 
 
 if __name__ == '__main__':
-  unittest.TextTestRunner(verbosity=2).run(suite())
+  import sys
+  result = unittest.TextTestRunner(verbosity=2).run(suite())
+  sys.exit(not result.wasSuccessful())
